==> cmsmadesimple-1.5.3.tgz: cms/modules/ModuleManager/lang/ext/pt_PT.php <==
<?php
$lang['use_at_your_own_risk'] = 'Use por sua conta e risco';
$lang['compatibility_disclaimer'] = 'Os m&oacute;dulos aqui  exibidos foram contribuidos tanto pelo CMS de desenvolvedores, e terceiros independentes. N&oacute;s n&atilde;o fazemos nenhuma garantia de que os m&oacute;dulos est&atilde;o dispon&iacute;veis aqui s&atilde;o funcionais, analisados, ou compat&iacute;vel com seu sistema. Voc&ecirc; &eacute; encorajado a ler as informa&ccedil;&otilde;es encontradas nos ajudar e cerca de liga&ccedil;&otilde;es para cada m&oacute;dulo antes de tentar a instala&ccedil;&atilde;o.';
$lang['notice'] = 'Aviso';
$lang['general_notice'] = 'As vers&otilde;es aqui exibidas representam os &uacute;ltimos arquivos XML carregados e seleccionados no seu reposit&oacute;rio  (geralmente o CMS %s). Eles podem ou n&atilde;o representar as &uacute;ltimas vers&otilde;es dispon&iacute;veis. Poder&aacute;  querer visualizar os arquivos seleccionados, dispon&iacute;veis em vers&otilde;es no reposit&oacute;rio. Se estiver a usar o reposit&oacute;rio padr&atilde;o, pode faz&ecirc;-lo, digitando o nome do m&oacute;dulo na caixa de pesquisa do %s e clicar no bot&atilde;o &quot;Arquivos&quot;.';
$lang['incompatible'] = 'Incompativel';
$lang['prompt_settings'] = 'Configura&ccedil;&otilde;es';
$lang['prompt_otheroptions'] = 'Outras Op&ccedil;&otilde;es';
$lang['reset'] = 'Redefinir';
$lang['error_permissions'] = '<strong><em>AVISO:</em></strong> Insuficientes permiss&otilde;es nos diret&oacute;rios para instalar m&oacute;dulos. Tamb&eacute;m pode estar enfrentando problemas com PHP Safe Mode. Verifique se o modo seguro est&aacute; desativado, e o sistema de arquivos que t&ecirc;m permiss&otilde;es s&atilde;o suficientes.';
$lang['error_minimumrepository'] = 'A vers&atilde;o do reposit&oacute;rio n&atilde;o &eacute; compat&iacute;vel com este m&oacute;dulo de gest&atilde;o';
$lang['prompt_reseturl'] = 'Redefinir URL para o padr&atilde;o';
$lang['prompt_resetcache'] = 'Redefinir o cache local do reposit&oacute;rio de dados';
$lang['prompt_dl_chunksize'] = 'Download tamanho (Kb)';
$lang['text_dl_chunksize'] = 'A quantidade m&aacute;xima de dados para download a partir do servidor em uma &uacute;nica vez (quando instalar um m&oacute;dulo)';
$lang['error_nofilesize'] = 'Nenhum par&acirc;metro relactivo ao tamanho foi fornecido';
$lang['error_nofilename'] = 'Nenhum par&acirc;metro relactivo ao tamanho foi fornecido';
$lang['error_checksum'] = 'Erro. Provavelmente indica um arquivo corrompido, quer quando foi carregado para o reposit&oacute;rio, ou um problema de tr&aacute;fego para a sua m&aacute;quina.';
$lang['cantdownload'] = 'N&atilde;o pode realizar o Download';
$lang['download'] = 'Download e Instala&ccedil;&atilde;o';
$lang['error_moduleinstallfailed'] = 'A instala&ccedil;&atilde;o do M&oacute;dulo falhou';
$lang['error_connectnomodules'] = 'Embora a liga&ccedil;&atilde;o tenha sido feita para o m&oacute;dulo especificado. Parece que este reposit&oacute;rio ainda n&atilde;o est&aacute; a compartilhar os m&oacute;dulos';
$lang['submit'] = 'Submeter';
$lang['text_repository_url'] = 'O URL deve estar no formato
http://www.mycmssite.com/path/soap.php?module=ModuleRepository';
$lang['prompt_repository_url'] = 'Module Repository URL:';
$lang['availmodules'] = 'M&oacute;dulos Dispon&iacute;veis';
$lang['preferences'] = 'Prefer&ecirc;ncias';
$lang['preferencessaved'] = 'Prefer&ecirc;ncias salvas';
$lang['repositorycount'] = 'M&oacute;dulos encontrados no reposit&oacute;rio';
$lang['instcount'] = 'M&oacute;dulos actualmente instalados';
$lang['availablemodules'] = 'O actual estado de m&oacute;dulos dispon&iacute;veis a partir do actual reposit&oacute;rio';
$lang['helptxt'] = 'Ajuda';
$lang['abouttxt'] = 'Cancelar';
$lang['xmltext'] = 'Arquivo XML';
$lang['nametext'] = 'M&oacute;dulo Nome';
$lang['vertext'] = 'Vers&atilde;o';
$lang['sizetext'] = 'Tamanho (Kilobytes)';
$lang['statustext'] = 'Estado/Ac&ccedil;&atilde;o';
$lang['uptodate'] = 'Instalado';
$lang['install'] = 'instalar';
$lang['newerversion'] = 'Vers&atilde;o mais recente instalada';
$lang['onlynewesttext'] = 'Mostrar somente a vers&atilde;o mais recente';
$lang['upgrade'] = 'Actualizar';
$lang['error_nosoapconnect'] = 'N&atilde;o consegue conectar ao SOAP servidor';
$lang['error_soaperror'] = 'Problema SOAP';
$lang['error_norepositoryurl'] = 'O URL para o M&oacute;dulo Reposit&oacute;rio n&atilde;o foi especificado';
$lang['friendlyname'] = 'Gestor de M&oacute;dulos';
$lang['postinstall'] = 'M&oacute;dulo Manager foi instalado com &ecirc;xito.';
$lang['postuninstall'] = 'M&oacute;dulo Manager foi desinstalado. Utilizadores deixar&atilde;o de ter a possibilidade de instalar m&oacute;dulos dos reposit&oacute;rios remotos. No entanto, a instala&ccedil;&atilde;o local ainda &eacute; poss&iacute;vel.';
$lang['really_uninstall'] = 'Tem certeza de que deseja desinstalar? Ficar&aacute; em falta um grande n&uacute;mero de funcionalidades.';
$lang['uninstalled'] = 'M&oacute;dulos Desinstalado';
$lang['installed'] = 'M&oacute;dulo vers&atilde;o %s instalado.';
$lang['upgraded'] = 'M&oacute;dulo actualizado vers&atilde;o %s';
$lang['moddescription'] = 'Um cliente para o ModuleRepository, este m&oacute;dulo permite a visualiza&ccedil;&atilde;o, e a instala&ccedil;&atilde;o de m&oacute;dulos a partir de locais remotos, sem a necessidade de ftping, ou unzipping de arquivos. M&oacute;dulo com arquivos XML s&atilde;o baixados usando SOAP, integridade verificada e, em seguida, expande-se automaticamente.';
$lang['error'] = 'Erro!';
$lang['admindescription'] = 'Uma ferramenta para recuperar e instalar m&oacute;dulos de servidores remotos.';
$lang['accessdenied'] = 'Acesso negado. Confira as suas permiss&otilde;es.';
$lang['changelog'] = '<ul>
<li>Version 1.0. 10 January 2006. Initial Release.</li>
<li>Version 1.1. July, 2006. Released with the 1.0- beta</li>
<li>Version 1.1.1 August, 2006.  Require 1.0.1 of nuSOAP</li>
<li>Version 1.1.2 September, 2006.  Fixed a mistake that resulted in upgrade not not working at all</li>
<li>Version 1.1.3 September, 2006.
  <ul>
  <li>Bumped minimum CMS Version to 1.0</li>
  <li>Now use 1 request to get the complete list of modules from the repository</li>
  <li>Added some missing lang strings</li>
  <li>Added the ability to reset the local cache of repository information</li>
  <li>Added the ability to restore the repository url to factory defaults</li>
  </ul>
</li>
<li>Version 1.1.4 February, 2007.  Now handles the safe mode check, and disables upgrading or installing modules if the permissions are wrong.</li>
<li>Version 1.1.5 September, 2007. New preference to make only latest module version show. Added nice message after saving preferences</li>
</li>
<li>Version 1.1.6 May, 2008. Now show if available modules are incompatible with the current CMS_VERSION.</li>
</li>
<li>Version 1.2 June, 2008.<br/>
This version should reduce the memory requirements of this module, and trade it off for performance on the server, and mroe requests to the server.
   <ul>
    <li>Bumped Minimum CMS Version to 1.3</li>
    <li>Bumped Minimum repository version to 1.1</li>
    <li>Get rid of all of the session stuff</li>
    <li>Add support for requesting modules beginning with a prefix (usually a single letter)</li>
    <li>Add support for requestion only the newest versions of the modules</li>
   </ul>
</li>
<li>Version 1.2.1 August, 2008.<br/>
Added a warning message to the top of the admin display.
</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>A client for the ModuleRepository, this module allows previewing, and installing modules from remote sites without the need for ftping, or unzipping archives.  Module XML files are downloaded using SOAP, integrity verified, and then expanded automatically.</p>
<h3>How Do I Use It</h3>
<p>In order to use this module, you will need the &#039;Modify Modules&#039; permission, and you will also need the complete, and full URL to a &#039;Module Repository&#039; installation.  You can specify this url in the &#039;Site Admin&#039; --> &#039;Global Settings&#039; page.</p><br/>
<p>You can find the interface for this module under the &#039;Extensions&#039; menu.  When you select this module, the &#039;Module Repository&#039; installation will automatically be queried for a list of it&#039;s available xml modules.  This list will be cross referenced with the list of currently installed modules, and a summary page displayed.  From here, you can view the descriptive information, the help, and the about information for a module without physically installing it.  You can also choose to upgrade or install modules.</p>
<h3>Support</h3>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
<h3>Tradu&ccedil;&atilde;o Portuguesa</h3>
<p>Copyright &copy; 2008, Nuno Costa <nuno.mfcosta@sapo.pt>.</p>';
$lang['utma'] = '156861353.2337628963718702600.1216609238.1216660189.1216662300.5';
$lang['utmz'] = '156861353.1216660189.4.2.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,23944.0.html';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.6.4.tgz: cms/modules/ModuleManager/lang/ext/pt_PT.php <==
<?php
$lang['available_updates'] = 'M&oacute;dulos dispon&iacute;veis para a Atualiza&ccedil;&atilde;o';
$lang['all_modules_up_to_date'] = 'N&atilde;o existem mais novos m&oacute;dulos dispon&iacute;veis no reposit&oacute;rio';
$lang['error_module_object'] = 'Erro: N&atilde;o foi poss&iacute;vel obter uma inst&acirc;ncia do m&oacute;dulo  %s';
$lang['error_nomatchingmodules'] = 'Erro: N&atilde;o foi poss&iacute;vel encontrar nenhuma correspond&ecirc;ncia dos m&oacute;dulos na pesquisar do reposit&oacute;rio ';
$lang['error_nomodules'] = 'Erro: N&atilde;o foi poss&iacute;vel obter lista dos m&oacute;dulos instalados';
$lang['upgrade_available'] = 'Vers&atilde;o mais recente dispon&iacute;vel (%s), a actual instalada &eacute; (%s)';
$lang['newversions'] = 'M&oacute;dulos instalados';
$lang['error_depends'] = 'Um ou mais depend&ecirc;ncias n&atilde;o est&atilde;o instaladas. Deve instalar as depend&ecirc;ncias primeiro';
$lang['msg_nodependencies'] = 'Este arquivo n&atilde;o tem quaisquer depend&ecirc;ncias enumeradas';
$lang['dependstxt'] = 'Depend&ecirc;ncias';
$lang['use_at_your_own_risk'] = 'Use por sua conta e risco';
$lang['compatibility_disclaimer'] = 'Os m&oacute;dulos aqui  exibidos foram contribu&iacute;dos tanto pelos desenvolvedores do CMS , e/ou terceiros independentes. N&oacute;s n&atilde;o damos nenhuma garantia de que os m&oacute;dulos dispon&iacute;veis aqui s&atilde;o funcionais, analisados, ou compat&iacute;vel com seu sistema. &Eacute; encorajado a ler as informa&ccedil;&otilde;es encontradas para nos ajudar &agrave; cerca de liga&ccedil;&otilde;es para cada m&oacute;dulo antes de tentar a instala&ccedil;&atilde;o.';
$lang['notice'] = 'Aviso';
$lang['general_notice'] = 'As vers&otilde;es aqui exibidas representam os &uacute;ltimos arquivos XML carregados e seleccionados no seu reposit&oacute;rio  (geralmente o CMS %s). Eles podem ou n&atilde;o representar as &uacute;ltimas vers&otilde;es dispon&iacute;veis. Poder&aacute;  querer visualizar os arquivos seleccionados, dispon&iacute;veis em vers&otilde;es no reposit&oacute;rio. Se estiver a usar o reposit&oacute;rio padr&atilde;o, pode faz&ecirc;-lo, digitando o nome do m&oacute;dulo na caixa de pesquisa do %s e clicar no bot&atilde;o &quot;Arquivos&quot;.';
$lang['incompatible'] = 'Incompativel';
$lang['prompt_settings'] = 'Configura&ccedil;&otilde;es';
$lang['prompt_otheroptions'] = 'Outras Op&ccedil;&otilde;es';
$lang['reset'] = 'Redefinir';
$lang['error_permissions'] = '<strong><em>AVISO:</em></strong> Insuficientes permiss&otilde;es nos diret&oacute;rios para instalar m&oacute;dulos. Tamb&eacute;m pode estar enfrentando problemas com PHP Safe Mode. Verifique se o modo seguro est&aacute; desativado, e o sistema de arquivos que t&ecirc;m permiss&otilde;es s&atilde;o suficientes.';
$lang['error_minimumrepository'] = 'A vers&atilde;o do reposit&oacute;rio n&atilde;o &eacute; compat&iacute;vel com este m&oacute;dulo de gest&atilde;o';
$lang['prompt_reseturl'] = 'Redefinir URL para o padr&atilde;o';
$lang['prompt_resetcache'] = 'Redefinir o cache local do reposit&oacute;rio de dados';
$lang['prompt_dl_chunksize'] = 'Download tamanho (Kb)';
$lang['text_dl_chunksize'] = 'A quantidade m&aacute;xima de dados para download a partir do servidor em uma &uacute;nica vez (quando instalar um m&oacute;dulo)';
$lang['error_nofilesize'] = 'Nenhum par&acirc;metro relactivo ao tamanho foi fornecido';
$lang['error_nofilename'] = 'Nenhum par&acirc;metro relactivo ao tamanho foi fornecido';
$lang['error_checksum'] = 'Erro. Provavelmente indica um arquivo corrompido, quer quando foi carregado para o reposit&oacute;rio, ou um problema de tr&aacute;fego para a sua m&aacute;quina.';
$lang['cantdownload'] = 'N&atilde;o pode realizar o Download';
$lang['download'] = 'Download e Instala&ccedil;&atilde;o';
$lang['error_moduleinstallfailed'] = 'A instala&ccedil;&atilde;o do M&oacute;dulo falhou';
$lang['error_connectnomodules'] = 'Embora a liga&ccedil;&atilde;o tenha sido feita para o m&oacute;dulo especificado. Parece que este reposit&oacute;rio ainda n&atilde;o est&aacute; a compartilhar os m&oacute;dulos';
$lang['submit'] = 'Submeter';
$lang['text_repository_url'] = 'O URL deve estar no formato
http://www.mycmssite.com/path/soap.php?module=ModuleRepository';
$lang['prompt_repository_url'] = 'Module Repository URL:';
$lang['availmodules'] = 'M&oacute;dulos Dispon&iacute;veis';
$lang['preferences'] = 'Prefer&ecirc;ncias';
$lang['preferencessaved'] = 'Prefer&ecirc;ncias salvas';
$lang['repositorycount'] = 'M&oacute;dulos encontrados no reposit&oacute;rio';
$lang['instcount'] = 'M&oacute;dulos actualmente instalados';
$lang['availablemodules'] = 'O actual estado de m&oacute;dulos dispon&iacute;veis a partir do actual reposit&oacute;rio';
$lang['helptxt'] = 'Ajuda';
$lang['abouttxt'] = 'Cancelar';
$lang['xmltext'] = 'Arquivo XML';
$lang['nametext'] = 'M&oacute;dulo Nome';
$lang['vertext'] = 'Vers&atilde;o';
$lang['sizetext'] = 'Tamanho (Kilobytes)';
$lang['statustext'] = 'Estado/Ac&ccedil;&atilde;o';
$lang['uptodate'] = 'Instalado';
$lang['install'] = 'instalar';
$lang['newerversion'] = 'Vers&atilde;o mais recente instalada';
$lang['onlynewesttext'] = 'Mostrar somente a vers&atilde;o mais recente';
$lang['upgrade'] = 'Actualizar';
$lang['error_nosoapconnect'] = 'N&atilde;o consegue conectar ao SOAP servidor';
$lang['error_soaperror'] = 'Problema SOAP';
$lang['error_norepositoryurl'] = 'O URL para o M&oacute;dulo Reposit&oacute;rio n&atilde;o foi especificado';
$lang['friendlyname'] = 'Gestor de M&oacute;dulos';
$lang['postinstall'] = 'M&oacute;dulo Manager foi instalado com &ecirc;xito.';
$lang['postuninstall'] = 'M&oacute;dulo Manager foi desinstalado. Utilizadores deixar&atilde;o de ter a possibilidade de instalar m&oacute;dulos dos reposit&oacute;rios remotos. No entanto, a instala&ccedil;&atilde;o local ainda &eacute; poss&iacute;vel.';
$lang['really_uninstall'] = 'Tem certeza de que deseja desinstalar? Ficar&aacute; em falta um grande n&uacute;mero de funcionalidades.';
$lang['uninstalled'] = 'M&oacute;dulos Desinstalado';
$lang['installed'] = 'M&oacute;dulo vers&atilde;o %s instalado.';
$lang['upgraded'] = 'M&oacute;dulo actualizado vers&atilde;o %s';
$lang['moddescription'] = 'Um cliente para o ModuleRepository, este m&oacute;dulo permite a visualiza&ccedil;&atilde;o, e a instala&ccedil;&atilde;o de m&oacute;dulos a partir de locais remotos, sem a necessidade de ftping, ou unzipping de arquivos. M&oacute;dulo com arquivos XML s&atilde;o baixados usando SOAP, integridade verificada e, em seguida, expande-se automaticamente.';
$lang['error'] = 'Erro!';
$lang['admindescription'] = 'Uma ferramenta para recuperar e instalar m&oacute;dulos de servidores remotos.';
$lang['accessdenied'] = 'Acesso negado. Confira as suas permiss&otilde;es.';
$lang['changelog'] = '<ul>
<li>Version 1.0. 10 January 2006. Initial Release.</li>
<li>Version 1.1. July, 2006. Released with the 1.0- beta</li>
<li>Version 1.1.1 August, 2006.  Require 1.0.1 of nuSOAP</li>
<li>Version 1.1.2 September, 2006.  Fixed a mistake that resulted in upgrade not not working at all</li>
<li>Version 1.1.3 September, 2006.
  <ul>
  <li>Bumped minimum CMS Version to 1.0</li>
  <li>Now use 1 request to get the complete list of modules from the repository</li>
  <li>Added some missing lang strings</li>
  <li>Added the ability to reset the local cache of repository information</li>
  <li>Added the ability to restore the repository url to factory defaults</li>
  </ul>
</li>
<li>Version 1.1.4 February, 2007.  Now handles the safe mode check, and disables upgrading or installing modules if the permissions are wrong.</li>
<li>Version 1.1.5 September, 2007. New preference to make only latest module version show. Added nice message after saving preferences</li>
</li>
<li>Version 1.1.6 May, 2008. Now show if available modules are incompatible with the current CMS_VERSION.</li>
</li>
<li>Version 1.2 June, 2008.<br/>
This version should reduce the memory requirements of this module, and trade it off for performance on the server, and mroe requests to the server.
   <ul>
    <li>Bumped Minimum CMS Version to 1.3</li>
    <li>Bumped Minimum repository version to 1.1</li>
    <li>Get rid of all of the session stuff</li>
    <li>Add support for requesting modules beginning with a prefix (usually a single letter)</li>
    <li>Add support for requestion only the newest versions of the modules</li>
   </ul>
</li>
<li>Version 1.2.1 August, 2008.<br/>
Added a warning message to the top of the admin display.
</li>
<li>Version 1.3 May, 2009.<br/>
Added dependency checking.
</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>A client for the ModuleRepository, this module allows previewing, and installing modules from remote sites without the need for ftping, or unzipping archives.  Module XML files are downloaded using SOAP, integrity verified, and then expanded automatically.</p>
<h3>How Do I Use It</h3>
<p>In order to use this module, you will need the &#039;Modify Modules&#039; permission, and you will also need the complete, and full URL to a &#039;Module Repository&#039; installation.  You can specify this url in the &#039;Extensions&#039; --&amp;gt; &#039;Module Manager&#039; --&amp;gt; &#039;Preferences&#039; page.</p><br/>
<p>You can find the interface for this module under the &#039;Extensions&#039; menu.  When you select this module, the &#039;Module Repository&#039; installation will automatically be queried for a list of it&#039;s available xml modules.  This list will be cross referenced with the list of currently installed modules, and a summary page displayed.  From here, you can view the descriptive information, the help, and the about information for a module without physically installing it.  You can also choose to upgrade or install modules.</p>
<h3>Support</h3>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com">&amp;lt;calguy1000@hotmail.com&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
<h3>Tradu&ccedil;&atilde;o Portuguesa</h3>
<p>Copyright &copy; 2008, Nuno Costa <nuno.mfcosta@sapo.pt>.</p>';
$lang['utma'] = '156861353.3089450601847726600.1241711306.1242169415.1242211460.31';
$lang['utmz'] = '156861353.1242165449.29.8.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
